<?php

namespace Litecms\LeadershipSetting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\LeadershipSetting\Models\LeadershipSetting;

class LeadershipSettingPolicy
{

    /**
     * Determine if the given user can view the leadership_setting.
     *
     * @param UserPolicy $user
     * @param LeadershipSetting $leadership_setting
     *
     * @return bool
     */
    public function view(UserPolicy $user, LeadershipSetting $leadership_setting)
    {
        if ($user->canDo('leadership_setting.leadership_setting.view') && $user->isAdmin()) {
            return true;
        }

        return $leadership_setting->user_id == user_id() && $leadership_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a leadership_setting.
     *
     * @param UserPolicy $user
     * @param LeadershipSetting $leadership_setting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('leadership_setting.leadership_setting.create');
    }

    /**
     * Determine if the given user can update the given leadership_setting.
     *
     * @param UserPolicy $user
     * @param LeadershipSetting $leadership_setting
     *
     * @return bool
     */
    public function update(UserPolicy $user, LeadershipSetting $leadership_setting)
    {
        if ($user->canDo('leadership_setting.leadership_setting.edit') && $user->isAdmin()) {
            return true;
        }

        return $leadership_setting->user_id == user_id() && $leadership_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given leadership_setting.
     *
     * @param UserPolicy $user
     * @param LeadershipSetting $leadership_setting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, LeadershipSetting $leadership_setting)
    {
        return $leadership_setting->user_id == user_id() && $leadership_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given leadership_setting.
     *
     * @param UserPolicy $user
     * @param LeadershipSetting $leadership_setting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, LeadershipSetting $leadership_setting)
    {
        if ($user->canDo('leadership_setting.leadership_setting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given leadership_setting.
     *
     * @param UserPolicy $user
     * @param LeadershipSetting $leadership_setting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, LeadershipSetting $leadership_setting)
    {
        if ($user->canDo('leadership_setting.leadership_setting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
